Learn R Programming

recmetrics (version 0.1.0)

append_observed_residuals: Append Observed Correlations to Data

Description

Compute observed residuals for each variables in data and appends these newly created variables to the original dataset.

Usage

append_observed_residuals(data, na.rm = TRUE)

Value

A numeric matrix of correlations among variable residuals.

Arguments

data

A data.frame or tibble

na.rm

logical (defaults to TRUE)

Examples

Run this code
  # Use the SCWB data example
  data(SCWB)
  append_observed_residuals(SCWB[, 1:20])

Run the code above in your browser using DataLab