powered by
Compute observed residuals for each variables in data and appends these newly created variables to the original dataset.
append_observed_residuals(data, na.rm = TRUE)
A numeric matrix of correlations among variable residuals.
A data.frame or tibble
logical (defaults to TRUE)
# Use the SCWB data example data(SCWB) append_observed_residuals(SCWB[, 1:20])
Run the code above in your browser using DataLab