Learn R Programming

recmetrics (version 0.1.0)

rec.avg.wb.domains: REC Metric 2

Description

For each domain i, the average of the REC entries within domain vs. the average of the REC entries when looking at correlations between indicators in domain D=i with indicators in domains other than i (note that this does NOT include correlations in domain j with other indicators in domain j; for a given domain, it is basically the average of the REC entries within the domain vs. the average of the REC entries for all of the other entries in the column of that domain). We might call this the REC domain coherence for domain i

Usage

rec.avg.wb.domains(data, domainlist = NULL, domainnames = NULL, na.rm = TRUE)

Value

A single numerical value

Arguments

data

A data.frame or tibble (required)

domainlist

A list of character vectors or numeric vectors denoting the columns for each domain (required)

domainnames

A character vector supplying updated names to be attached to output

na.rm

logical (defaults to TRUE)

Details

[Experimental]

Examples

Run this code
  # Use the SCWB data example
  mylist <- list(
    domain_goodrel = c("cwbcloserel", "cwbrespect", "cwbtrust", "cwbmutuality"),
    domain_prolead = c("cwbbeneficence", "cwbintegrity", "cwbcompetence", "cwbvision"),
    domain_healthyprac = c("cwbrelgrowth", "cwbfairness", "cwbsustenance", "cwbachieve"),
    domain_satcomm = c("cwbsatisf", "cwbvalue", "cwbbelonging", "cwbwelcome"),
    domain_strongmiss = c("cwbpurpose", "cwbcontrib", "cwbinterconn", "cwbsynergy")
  )
  rec.avg.wb.domains(SCWB, mylist)

Run the code above in your browser using DataLab